/* eip97_global_types.h
 *
 * EIP97 Global Control Driver Library Public Interface:
 * Common Type Definitions
 *
 */

/* -------------------------------------------------------------------------- */
/*                                                                            */
/*   Module        : ddk197                                                   */
/*   Version       : 5.6.1                                                    */
/*   Configuration : DDK-197-GPL                                              */
/*                                                                            */
/*   Date          : 2022-Dec-16                                              */
/*                                                                            */
/* Copyright (c) 2008-2022 by Rambus, Inc. and/or its subsidiaries.           */
/*                                                                            */
/* This program is free software: you can redistribute it and/or modify       */
/* it under the terms of the GNU General Public License as published by       */
/* the Free Software Foundation, either version 2 of the License, or          */
/* any later version.                                                         */
/*                                                                            */
/* This program is distributed in the hope that it will be useful,            */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of             */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the               */
/* GNU General Public License for more details.                               */
/*                                                                            */
/* You should have received a copy of the GNU General Public License          */
/* along with this program. If not, see <http://www.gnu.org/licenses/>.       */
/* -------------------------------------------------------------------------- */

#ifndef INCLUDE_GUARD_EIP97_GLOBAL_TYPES_H
#define INCLUDE_GUARD_EIP97_GLOBAL_TYPES_H

/*----------------------------------------------------------------------------
 * This module uses (requires) the following interface(s):
 */

// Driver Framework Basic Definitions API
#include "basic_defs.h"             // uint32_t


/*----------------------------------------------------------------------------
 * Definitions and macros
 */

#define EIP97_GLOBAL_IOAREA_REQUIRED_SIZE       (2 * sizeof(void*))

/*----------------------------------------------------------------------------
 * EIP97_Global_Error_t
 *
 * Status (error) code type returned by these API functions
 * See each function "Return value" for details.
 *
 * EIP97_GLOBAL_NO_ERROR : successful completion of the call.
 * EIP97_GLOBAL_UNSUPPORTED_FEATURE_ERROR : not supported by the device.
 * EIP97_GLOBAL_ARGUMENT_ERROR :  invalid argument for a function parameter.
 * EIP97_GLOBAL_BUSY_RETRY_LATER : Device is busy.
 * EIP97_GLOBAL_ILLEGAL_IN_STATE : illegal state transition
 */
typedef enum
{
    EIP97_GLOBAL_NO_ERROR = 0,
    EIP97_GLOBAL_UNSUPPORTED_FEATURE_ERROR,
    EIP97_GLOBAL_ARGUMENT_ERROR,
    EIP97_GLOBAL_BUSY_RETRY_LATER,
    EIP97_GLOBAL_ILLEGAL_IN_STATE
} EIP97_Global_Error_t;

/*----------------------------------------------------------------------------
 * EIP97_Global_Events_t
 *
 * Bit-mask for the events that can be generated by the EIP-97 HW modules:
 * DFE, DSE, EIP-96 PE
 */
typedef enum
{
    // Fatal error events
    EIP97_GLOBAL_DFE_DMA_ERROR_EVENT = BIT_0,
    EIP97_GLOBAL_DSE_DMA_ERROR_EVENT = BIT_1,
    EIP97_GLOBAL_PE_TIMEOUT_EVENT    = BIT_2
} EIP97_Global_Events_t;

// Bit-mask for the events defined by EIP97_Global_Events_t
typedef uint32_t EIP97_Global_EventStatus_t;

// place holder for device specific internal data
typedef struct
{
    uint32_t placeholder[EIP97_GLOBAL_IOAREA_REQUIRED_SIZE];
} EIP97_Global_IOArea_t;


#endif /* INCLUDE_GUARD_EIP97_GLOBAL_TYPES_H */


/* end of file eip97_global_types.h */
